@@ -631,30 +631,17 @@ Rose::HTML::Form::Field - HTML form field base class.
 
 =head1 DESCRIPTION
 
-L<Rose::HTML::Form::Field> is the base class for field objects used in an HTML
-form.  It defines a generic interface for field input, output, validation, and
-filtering.
+L<Rose::HTML::Form::Field> is the base class for field objects used in an HTML form.  It defines a generic interface for field input, output, validation, and filtering.
 
-This class inherits from, and follows the conventions of,
-L<Rose::HTML::Object>. Inherited methods that are not overridden will not be
-documented a second time here.  See the L<Rose::HTML::Object> documentation
-for more information.
+This class inherits from, and follows the conventions of, L<Rose::HTML::Object>. Inherited methods that are not overridden will not be documented a second time here.  See the L<Rose::HTML::Object> documentation for more information.
 
 =head1 OVERVIEW
 
-A field object provides an interface for a logical field in an HTML form. 
-Although it may serialize to multiple HTML tags, the field object itself is a
-single, logical entity.
+A field object provides an interface for a logical field in an HTML form. Although it may serialize to multiple HTML tags, the field object itself is a single, logical entity.
 
-L<Rose::HTML::Form::Field> is the base class for field objects.   Since the
-field object will eventually be asked to serialize itself as HTML,
-L<Rose::HTML::Form::Field> inherits from L<Rose::HTML::Object>.  That defines
-a lot of a field object's interface, leaving only the field-specific functions
-to L<Rose::HTML::Form::Field> itself.
+L<Rose::HTML::Form::Field> is the base class for field objects.   Since the field object will eventually be asked to serialize itself as HTML, L<Rose::HTML::Form::Field> inherits from L<Rose::HTML::Object>.  That defines a lot of a field object's interface, leaving only the field-specific functions to L<Rose::HTML::Form::Field> itself.
 
-The most important function of a field object is to accept and return user
-input.  L<Rose::HTML::Form::Field> defines a data flow for field values with
-several different hooks and callbacks along the way:
+The most important function of a field object is to accept and return user input.  L<Rose::HTML::Form::Field> defines a data flow for field values with several different hooks and callbacks along the way:
 
                         +------------+
                        / user input /
@@ -714,10 +701,7 @@ several different hooks and callbacks along the way:
                     +------------------+
 
 
-Input must be done "at the top", by calling C<input_value()>. The value as
-it exists at various stages of the flow can be retrieved, but it can only be
-set at the top.  Input and output filters can be defined, but none exist by
-default.
+Input must be done "at the top", by calling L<input_value()|/input_value>. The value as it exists at various stages of the flow can be retrieved, but it can only be set at the top.  Input and output filters can be defined, but none exist by default.
 
 The purposes of the various stages of the data flow are as follows:
 
@@ -729,72 +713,35 @@ The value as it was passed to the field.
 
 =item B<input value filtered>
 
-The input value after being passed through all input filters, but
-before being inflated.
+The input value after being passed through all input filters, but before being inflated.
 
 =item B<internal value>
 
-The most useful representation of the value as far as the user of the
-L<Rose::HTML::Form::Field>-derived class is concerned.  It has been filtered
-and optionally "inflated" into a richer representation (i.e., an object).
-The internal value must also be a valid input value.
+The most useful representation of the value as far as the user of the L<Rose::HTML::Form::Field>-derived class is concerned.  It has been filtered and optionally "inflated" into a richer representation (i.e., an object). The internal value must also be a valid input value.
 
 =item B<output value>
 
-The value as it will be used in the serialized HTML representation of the
-field, as well as in the equivalent URI query string.  This is the internal
-value after being optionally "deflated" and then passed through an output
-filter. This value should be a string or a reference to an arry of strings. If
-passed back into the field as the input value, it should result in the same
-output value.
+The value as it will be used in the serialized HTML representation of the field, as well as in the equivalent URI query string.  This is the internal value after being optionally "deflated" and then passed through an output filter. This value should be a string or a reference to an arry of strings. If passed back into the field as the input value, it should result in the same output value.
 
 =back
 
-Only subclasses can define class-wide "inflate" and "deflate" methods (by
-overriding the no-op implementations in this class), but users can define
-input and output filters on a per-object basis by passing code references to
-the appropriate object methods.
+Only subclasses can define class-wide "inflate" and "deflate" methods (by overriding the no-op implementations in this class), but users can define input and output filters on a per-object basis by passing code references to the appropriate object methods.
 
-The prefilter exists to handle common filtering tasks without hogging
-the lone input filter spot (or requiring users to constantly set
-input filters for every field).  The L<Rose::HTML::Form::Field> prefilter
-optionally trims leading and trailing whitespace based on the value of
-the C<trim_spaces()> boolean attribute.  This is part of the public
-API for field objects, so subclasses that override C<input_prefilter()>
-must preserve this functionality.
+The prefilter exists to handle common filtering tasks without hogging the lone input filter spot (or requiring users to constantly set input filters for every field).  The L<Rose::HTML::Form::Field> prefilter optionally trims leading and trailing whitespace based on the value of the L<trim_spaces()|/trim_spaces> boolean attribute.  This is part of the public API for field objects, so subclasses that override L<input_prefilter()|/input_prefilter> must preserve this functionality.
 
-In addition to the various kinds of field values, each field also has a name,
-which may or may not be the same as the value of the "name" HTML attribute.
+In addition to the various kinds of field values, each field also has a name, which may or may not be the same as the value of the "name" HTML attribute.
 
-Fields also have associated labels, error strings, default values, and various
-methods for testing, clearing, and reseting the field value.  See the list of
-object methods below for the details.
+Fields also have associated labels, error strings, default values, and various methods for testing, clearing, and reseting the field value.  See the list of object methods below for the details.
 
 =head1 CUSTOM FIELDS
 
-This module distribution contains classes for most simple HTML fields, as well
-as examples of several more complex field types.  These "custom" fields do
-things like accept only valid email addresses or dates, coerce input and
-output into fixed formats, and provide rich internal representations (e.g.,
-C<DateTime> objects).  Compound fields are made up of more than one field, and
-this construction can be nested: compound fields can contain other compound
-fields.  So long as each custom field class complies with the API outlined
-here, it doesn't matter how complex it is internally (or externally, in its
-HTML serialization).
+This module distribution contains classes for most simple HTML fields, as well as examples of several more complex field types.  These "custom" fields do things like accept only valid email addresses or dates, coerce input and output into fixed formats, and provide rich internal representations (e.g., L<DateTime> objects).  Compound fields are made up of more than one field, and this construction can be nested: compound fields can contain other compound fields.  So long as each custom field class complies with the API outlined here, it doesn't matter how complex it is internally (or externally, in its HTML serialization).
 
-(There are, however, certain rules that compound fields must follow in order to
-work correctly inside L<Rose::HTML::Form> objects.  See the
-L<Rose::HTML::Form::Field::Compound> documentation for more information.)
+(There are, however, certain rules that compound fields must follow in order to work correctly inside L<Rose::HTML::Form> objects.  See the L<Rose::HTML::Form::Field::Compound> documentation for more information.)
 
-All of these classes are meant to be a starting point for your own custom
-fields.  The custom fields included in this module distribution are mostly
-meant as examples of what can be done.  I will accept any useful, interesting
-custom field classes into the C<Rose::HTML::Form::Field::*> namespace, but I'd
-also like to encourage suites of custom field classes in other namespaces
-entirely.  Remember, subclassing doesn't necessarily dictate namespace.
+All of these classes are meant to be a starting point for your own custom fields.  The custom fields included in this module distribution are mostly meant as examples of what can be done.  I will accept any useful, interesting custom field classes into the C<Rose::HTML::Form::Field::*> namespace, but I'd also like to encourage suites of custom field classes in other namespaces entirely.  Remember, subclassing doesn't necessarily dictate namespace.
 
-Building up a library of custom fields is almost always a big win in the long
-run.  Reuse, reuse, reuse!
+Building up a library of custom fields is almost always a big win in the long run.  Reuse, reuse, reuse!
 
 =head1 HTML ATTRIBUTES
 
@@ -847,52 +794,35 @@ See L</"parent_field"> and L</"invalidate_value"> for more information.
 
 =item B<clear>
 
-Clears the field by setting both the "value" HTML attribute and the input
-value to undef.  Also sets the C<is_cleared()> flag.
+Clears the field by setting both the "value" HTML attribute and the input value to undef.  Also sets the L<is_cleared()|/is_cleared> flag.
 
 =item B<default VALUE>
 
-Convenience wrapper for C<default_value()>
+Convenience wrapper for L<default_value()|/default_value>
 
 =item B<default_value VALUE>
 
-Set the default value for the field.  In the absence of a defined input value,
-the default value is used as the input value.
+Set the default value for the field.  In the absence of a defined input value, the default value is used as the input value.
 
 =item B<deflate_value VALUE>
 
-This method is meant to be overridden by a subclass.  It should take VALUE and
-"deflate" it to a form that is a suitable for the output value: a string or
-reference to an array of strings.  The implementation in
-L<Rose::HTML::Form::Field> simply returns VALUE unmodified.
+This method is meant to be overridden by a subclass.  It should take VALUE and "deflate" it to a form that is a suitable for the output value: a string or reference to an array of strings.  The implementation in L<Rose::HTML::Form::Field> simply returns VALUE unmodified.
 
 =item B<description [TEXT]>
 
-Get or set a text description of the field.  This text is not currently used
-anywhere, but may be in the future.  It may be useful as help text, but keep
-in mind that any such text should stay true to its intended purpose: a
-description of the field.
+Get or set a text description of the field.  This text is not currently used anywhere, but may be in the future.  It may be useful as help text, but keep in mind that any such text should stay true to its intended purpose: a description of the field.
 
-Going too far off into the realm of generic help text is not a good idea
-since this text may be used elsewhere by this class or subclasses, and there
-it will be expected to be a description of the field rather than a description
-of how to fill out the field (e.g. "Command-click to make multiple
-selections") or any other sort of help text.
+Going too far off into the realm of generic help text is not a good idea since this text may be used elsewhere by this class or subclasses, and there it will be expected to be a description of the field rather than a description of how to fill out the field (e.g. "Command-click to make multiple selections") or any other sort of help text.
 
 It may also be useful for debugging.
 
 =item B<field_name [NAME]>
 
-When passed a NAME argument, it sets the name of the field.  If the "name"
-HTML attribute is not defined, its value is also set to NAME.  NAME is then
-returned.
+When passed a NAME argument, it sets the name of the field.  If the "name" HTML attribute is not defined, its value is also set to NAME.  NAME is then returned.
 
-If no arguments are passed, and if the field name is not defined, then the
-field name is set to the value of the "name" HTML attribute and then returned.
-If the field name was already defined, then it is simply returned.
+If no arguments are passed, and if the field name is not defined, then the field name is set to the value of the "name" HTML attribute and then returned. If the field name was already defined, then it is simply returned.
 
-Note that this means that the field name and the "name" HTML attribute do not
-necessarily have to be the same (but usually are).
+Note that this means that the field name and the "name" HTML attribute do not necessarily have to be the same (but usually are).
 
 =item B<filter [CODE]>
 
@@ -900,23 +830,19 @@ Sets both the input filter and output filter to CODE.
 
 =item B<hidden_field>
 
-Convenience wrapper for C<hidden_fields()>
+Convenience wrapper for L<hidden_fields()|/hidden_fields>
 
 =item B<hidden_fields>
 
-Returns one or more L<Rose::HTML::Form::Field::Hidden> objects that represent
-the hidden fields needed to encode this field's value.
+Returns one or more L<Rose::HTML::Form::Field::Hidden> objects that represent the hidden fields needed to encode this field's value.
 
 =item B<html>
 
-Returns the HTML serialization of the field, along with the HTML error
-message, if any. The field and error HTML are joined by
-C<html_error_separator()>, which is "E<lt>brE<gt>\n" by default.
+Returns the HTML serialization of the field, along with the HTML error message, if any. The field and error HTML are joined by L<html_error_separator()|/html_error_separator>, which is "E<lt>brE<gt>\n" by default.
 
 =item B<html_error_separator [STRING]>
 
-Get or set the string used to join the HTML field and HTML error message
-in the output of the C<html()> method.  The default value is "E<lt>brE<gt>\n"
+Get or set the string used to join the HTML field and HTML error message in the output of the L<html()|/html> method.  The default value is "E<lt>brE<gt>\n"
 
 =item B<html_field>
 
@@ -924,47 +850,33 @@ Returns the HTML serialization of the field.
 
 =item B<html_hidden_field>
 
-Convenience wrapper for C<html_hidden_fields()>
+Convenience wrapper for L<html_hidden_fields()|/html_hidden_fields>
 
 =item B<html_hidden_fields>
 
-Returns the HTML serialization of the fields returned by C<hidden_fields()>,
-joined by newlines.
+Returns the HTML serialization of the fields returned by L<hidden_fields()|/hidden_fields>, joined by newlines.
 
 =item B<html_label [ARGS]>
 
-Returns the HTML serialization of the label object, or the empty
-string if the field's C<label> is undefined or zero in length.
-Any ARGS are passed to the call to C<label_object()>.
+Returns the HTML serialization of the label object, or the empty string if the field's C<label> is undefined or zero in length. Any ARGS are passed to the call to L<label_object()|/label_object>.
 
-If C<required()>is true for this field, then the name/value pair "class =>
-'required'" is passed to the call to C<label_object()> I<before> any
-arguments that you pass.  This allows you to override the "class" value
-with one of your own.
+If L<required()|/required>is true for this field, then the name/value pair "class => 'required'" is passed to the call to L<label_object()|/label_object> I<before> any arguments that you pass.  This allows you to override the "class" value with one of your own.
 
 =item B<html_prefix [STRING]>
 
-Get or set an HTML prefix that may be displayed before the HTML field.
-L<Rose::HTML::Form::Field> does not use this prefix, but subclasses might.
-The default value is an empty string.
+Get or set an HTML prefix that may be displayed before the HTML field. L<Rose::HTML::Form::Field> does not use this prefix, but subclasses might. The default value is an empty string.
 
 =item B<html_suffix [STRING]>
 
-Get or set an HTML suffix that may be appended to the HTML field.
-L<Rose::HTML::Form::Field> does not use this suffix, but subclasses might.
-The default value is an empty string.
+Get or set an HTML suffix that may be appended to the HTML field. L<Rose::HTML::Form::Field> does not use this suffix, but subclasses might. The default value is an empty string.
 
 =item B<html_tag>
 
-This method is part of the L<Rose::HTML::Object> API.  In this case, it simply
-calls C<html_field()>.
+This method is part of the L<Rose::HTML::Object> API.  In this case, it simply calls L<html_field()|/html_field>.
 
 =item B<inflate_value VALUE>
 
-This method is meant to be overridden by subclasses.  It should take VALUE and
-"inflate" it to a form that is a suitable internal value.  (See the
-L<OVERVIEW> for more on internal values.)  The default implementation simply
-returns its first argument unmodified.
+This method is meant to be overridden by subclasses.  It should take VALUE and "inflate" it to a form that is a suitable internal value.  (See the L<OVERVIEW> for more on internal values.)  The default implementation simply returns its first argument unmodified.
 
 =item B<input_filter [CODE]>
 
@@ -972,14 +884,9 @@ Get or set the input filter.
 
 =item B<input_prefilter VALUE>
 
-Runs VALUE through the input prefilter.  This method is called automatically
-when needed and is not meant to be called by users of this module.  Subclasses
-may want to override it, however. 
+Runs VALUE through the input prefilter.  This method is called automatically when needed and is not meant to be called by users of this module.  Subclasses may want to override it, however.
 
-The default implementation optionally trims leading and trailing spaces based
-on the value of the C<trim_spaces()> boolean attribute.  This is part of the
-public API for field objects, so subclasses that override C<input_prefilter()>
-must preserve this functionality.
+The default implementation optionally trims leading and trailing spaces based on the value of the L<trim_spaces()|/trim_spaces> boolean attribute.  This is part of the public API for field objects, so subclasses that override L<input_prefilter()|/input_prefilter> must preserve this functionality.
 
 =item B<input_value [VALUE]>
 
@@ -987,8 +894,7 @@ Get or set the input value.
 
 =item B<input_value_filtered>
 
-Returns the input value after passing it through the input prefilter
-and input filter (if any).
+Returns the input value after passing it through the input prefilter and input filter (if any).
 
 =item B<internal_value>
 
@@ -1006,9 +912,7 @@ This method is most useful in conjunction with the L</"parent_field"> attribute.
 
 =item B<is_cleared>
 
-Returns true if the field is cleared (i.e., if C<clear()> has been called on
-it and it has not subsequently been C<reset()> or given a new input value),
-false otherwise.
+Returns true if the field is cleared (i.e., if L<clear()|/clear> has been called on it and it has not subsequently been L<reset()|/reset> or given a new input value), false otherwise.
 
 =item B<is_empty>
 
@@ -1020,23 +924,15 @@ Returns true if the internal value contains any non-whitespace characters, false
 
 =item B<label [STRING]>
 
-Get or set the field label.  This label is used by the various label printing
-methods as well as in some default error messages.  Even if you don't plan to
-use any of the former, it might be a good idea to set it to a sensible value
-for use in the latter.
+Get or set the field label.  This label is used by the various label printing methods as well as in some default error messages.  Even if you don't plan to use any of the former, it might be a good idea to set it to a sensible value for use in the latter.
 
 =item B<label_object [ARGS]>
 
-Returns a L<Rose::HTML::Label> object with its C<for> HTML attribute set to
-the calling field's C<id> attribute and any other HTML attributes specified by
-the name/value pairs in ARGS.  The HTML contents of the label object are set
-to the field's C<label()>, which has its HTML escaped if C<escape_html()> is
-true (which is the default).
+Returns a L<Rose::HTML::Label> object with its C<for> HTML attribute set to the calling field's C<id> attribute and any other HTML attributes specified by the name/value pairs in ARGS.  The HTML contents of the label object are set to the field's L<label()|/label>, which has its HTML escaped if L<escape_html()|Rose::HTML::Object/escape_html> is true (which is the default).
 
 =item B<name [NAME]>
 
-Get or set the "name" HTML attribute, but return the C<field_name()>
-if the "name" HTML attribute is undefined.
+Get or set the "name" HTML attribute, but return the L<field_name()|/field_name> if the "name" HTML attribute is undefined.
 
 =item B<output_filter [CODE]>
 
@@ -1048,86 +944,63 @@ Returns the output value.
 
 =item B<parent_field [FIELD]>
 
-Get or set the parent field.  This method is provided for the benefit of
-subclasses that might want to have a hierarchy of field objects.  The
-reference to the parent field is "weakened" using C<Scalar::Util::weaken()> in
-order to avoid memory leaks caused by circular references.
+Get or set the parent field.  This method is provided for the benefit of subclasses that might want to have a hierarchy of field objects.  The reference to the parent field is "weakened" using C<Scalar::Util::weaken()> in order to avoid memory leaks caused by circular references.
 
 =item B<required [BOOL]>
 
-Get to set a boolean flag that indicates whether or not a field is "required."
-See C<validate()> for more on what "required" means.
+Get to set a boolean flag that indicates whether or not a field is "required." See L<validate()|/validate> for more on what "required" means.
 
 =item B<reset>
 
-Reset the field to its default state: the input value and C<error()> are set
-to undef and the C<is_cleared()> flag is set to false.
+Reset the field to its default state: the input value and L<error()|Rose::HTML::Object/error> are set to undef and the L<is_cleared()|/is_cleared> flag is set to false.
 
 =item B<trim_spaces [BOOL]>
 
-Get or set the boolean flag that indicates whether or not leading and trailing
-spaces should be removed from the field value in the input prefilter.
-The default is true.
+Get or set the boolean flag that indicates whether or not leading and trailing spaces should be removed from the field value in the input prefilter. The default is true.
 
 =item B<validate>
 
-Validate the field and return a true value if it is valid, false otherwise. If
-the field is C<required>, then its internal value is tested according to the
-following rules.
+Validate the field and return a true value if it is valid, false otherwise. If the field is C<required>, then its internal value is tested according to the following rules.
 
 * If the internal value is undefined, then return false.
 
-* If the internal value is a reference to an array, and the array is empty,
-then return false.
+* If the internal value is a reference to an array, and the array is empty, then return false.
 
-* If C<trim_spaces()> is true (the default) and if the internal value does not
-contain any non-whitespace characters, return false.
+* If L<trim_spaces()|/trim_spaces> is true (the default) and if the internal value does not contain any non-whitespace characters, return false.
 
-If false is returned due to one of the conditions above, then C<error()> is
-set to the string:
+If false is returned due to one of the conditions above, then L<error()|Rose::HTML::Object/error> is set to the string:
 
     $label is a required field
 
-where C<$label> is either the field's C<label()> or, if C<label()> is not
-defined, the string "This".
+where C<$label> is either the field's L<label()|/label> or, if L<label()|/label> is not defined, the string "This".
 
-If a custom C<validator()> is set, then C<$_> is localized and set to the
-internal value and the validator subroutine is called with the field object
-as the first and only argument.
+If a custom L<validator()|/validator> is set, then C<$_> is localized and set to the internal value and the validator subroutine is called with the field object as the first and only argument.
 
-If the validator subroutine returns false and did not set C<error()> to a
-defined value, then C<error()> is set to the string:
+If the validator subroutine returns false and did not set L<error()|Rose::HTML::Object/error> to a defined value, then L<error()|Rose::HTML::Object/error> is set to the string:
 
     $label is invalid
 
-where C<$label> is is either the field's C<label()> or, if C<label()> is not
-defined, the string "Value".
+where C<$label> is is either the field's L<label()|/label> or, if L<label()|/label> is not defined, the string "Value".
 
 The return value of the validator subroutine is then returned.
 
-If none of the above tests caused a value to be returned, then true is
-returned.
+If none of the above tests caused a value to be returned, then true is returned.
 
 =item B<validator [CODE]>
 
-Get or set a validator subroutine.  If defined, this subroutine is called by
-C<validate()>.
+Get or set a validator subroutine.  If defined, this subroutine is called by L<validate()|/validate>.
 
 =item B<value [VALUE]>
 
-If a VALUE argument is passed, it sets both the input value and the "value"
-HTML attribute to VALUE.  Returns the value of the "value" HTML attribute.
+If a VALUE argument is passed, it sets both the input value and the "value" HTML attribute to VALUE.  Returns the value of the "value" HTML attribute.
 
 =item B<xhtml>
 
-Returns the XHTML serialization of the field, along with the HTML error
-message, if any. The field and error HTML are joined by
-C<xhtml_error_separator()>, which is "E<lt>br /E<gt>\n" by default.
+Returns the XHTML serialization of the field, along with the HTML error message, if any. The field and error HTML are joined by L<xhtml_error_separator()|/xhtml_error_separator>, which is "E<lt>br /E<gt>\n" by default.
 
 =item B<xhtml_error_separator [STRING]>
 
-Get or set the string used to join the XHTML field and HTML error message
-in the output of the C<xhtml()> method.  The default value is "E<lt>br /E<gt>\n"
+Get or set the string used to join the XHTML field and HTML error message in the output of the L<xhtml()|/xhtml> method.  The default value is "E<lt>br /E<gt>\n"
 
 =item B<xhtml_field>
 
@@ -1135,37 +1008,38 @@ Returns the XHTML serialization of the field.
 
 =item B<xhtml_hidden_field>
 
-Convenience wrapper for C<xhtml_hidden_fields()>
+Convenience wrapper for L<xhtml_hidden_fields()|/xhtml_hidden_fields>
 
 =item B<xhtml_hidden_fields>
 
-Returns the XHTML serialization of the fields returned by C<hidden_fields()>,
-joined by newlines.
+Returns the XHTML serialization of the fields returned by L<hidden_fields()|/hidden_fields>, joined by newlines.
 
 =item B<xhtml_label [ARGS]>
 
-Returns the XHTML serialization of the label object, or the empty
-string if the field's C<label> is undefined or zero in length.
-Any ARGS are passed to the call to C<label_object()>.
+Returns the XHTML serialization of the label object, or the empty string if the field's C<label> is undefined or zero in length. Any ARGS are passed to the call to L<label_object()|/label_object>.
 
-If C<required()>is true for this field, then the name/value pair "class =>
-'required'" is passed to the call to C<label_object()> I<before> any
-arguments that you pass.  This allows you to override the "class" value
-with one of your own.
+If L<required()|/required>is true for this field, then the name/value pair "class => 'required'" is passed to the call to L<label_object()|/label_object> I<before> any arguments that you pass.  This allows you to override the "class" value with one of your own.
 
 =item B<xhtml_tag>
 
-This method is part of the L<Rose::HTML::Object> API.  In this case, it simply
-calls C<xhtml_field()>.
+This method is part of the L<Rose::HTML::Object> API.  In this case, it simply calls L<xhtml_field()|/xhtml_field>.
 
 =back
 
+=head1 SUPPORT
+
+Any L<Rose::HTML::Objects> questions or problems can be posted to the L<Rose::HTML::Objects> mailing list.  To subscribe to the list or view the archives, go here:
+
+L<http://lists.sourceforge.net/lists/listinfo/rose-html-objects>
+
+Although the mailing list is the preferred support mechanism, you can also email the author (see below) or file bugs using the CPAN bug tracking system:
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Rose-HTML-Objects>
+
 =head1 AUTHOR
 
 John C. Siracusa (siracusa@mindspring.com)
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005 by John C. Siracusa.  All rights reserved.  This program is
-free software; you can redistribute it and/or modify it under the same terms
-as Perl itself.
+Copyright (c) 2005 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
